@@ -1,6 +1,8 @@
-#!/bin/env perl 
+#!perl -w
 #!d:\perl\bin\perl.exe 
 
+# -- UDDI::Lite -- soaplite.com -- Copyright (C) 2001 Paul Kulchenko --
+
 use UDDI::Lite +autodispatch =>
   proxy => 'http://uddi.microsoft.com/inquire',
 ;
@@ -8,6 +10,6 @@ use UDDI::Lite +autodispatch =>
 my $list = find_business(name => 'microsoft');
 my $bis = $list->businessInfos;
 for ($bis->businessInfo) {
-  my $s = $_->serviceInfos->serviceInfo;
+  my $s = $_->serviceInfos->serviceInfo or next; # skip if no service information
   print $s->name, ' ', $s->businessKey, "\n";
 }
