@@ -7,5 +7,5 @@ use SOAP::Lite;
 
 # object interface
 print SOAP::Lite
-  -> service('http://www.xmethods.net/sd/StockQuoteService.wsdl')
+  -> service('http://services.xmethods.net/soap/urn:xmethods-delayed-quotes.wsdl')
   -> getQuote('MSFT'), "\n";
